@@ -13,7 +13,6 @@
 from __future__ import (absolute_import, unicode_literals)
 
 import atexit
-import collections
 import errno
 import os
 import pwd
@@ -761,9 +760,8 @@ def is_socket(fd):
         """
     result = False
 
-    file_socket = socket.fromfd(fd, socket.AF_INET, socket.SOCK_RAW)
-
     try:
+        file_socket = socket.fromfd(fd, socket.AF_INET, socket.SOCK_RAW)
         file_socket.getsockopt(socket.SOL_SOCKET, socket.SO_TYPE)
     except socket.error as exc:
         exc_errno = exc.args[0]
@@ -891,10 +889,6 @@ def _get_candidate_file_descriptors(exclude):
     return candidates
 
 
-FileDescriptorRange = collections.namedtuple(
-        'FileDescriptorRange', ['low', 'high'])
-
-
 def _get_candidate_file_descriptor_ranges(exclude):
     """ Get the collection of candidate file descriptor ranges.
 
@@ -913,35 +907,42 @@ def _get_candidate_file_descriptor_ranges(exclude):
         """
     candidates_list = sorted(_get_candidate_file_descriptors(exclude))
     ranges = []
-    this_range = FileDescriptorRange(
-            low=min(candidates_list),
-            high=(min(candidates_list) + 1))
+
+    def append_range_if_needed(candidate_range):
+        (low, high) = candidate_range
+        if (low < high):
+            # The range is not empty.
+            ranges.append(candidate_range)
+
+    this_range = (
+        (min(candidates_list), (min(candidates_list) + 1))
+        if candidates_list else (0, 0))
     for fd in candidates_list[1:]:
         high = fd + 1
-        if this_range.high == fd:
+        if this_range[1] == fd:
             # This file descriptor extends the current range.
-            this_range = this_range._replace(high=high)
+            this_range = (this_range[0], high)
         else:
             # The previous range has ended at a gap.
-            ranges.append(this_range)
+            append_range_if_needed(this_range)
             # This file descriptor begins a new range.
-            this_range = FileDescriptorRange(low=fd, high=high)
-    ranges.append(this_range)
+            this_range = (fd, high)
+    append_range_if_needed(this_range)
     return ranges
 
 
 def _close_file_descriptor_ranges(ranges):
     """ Close file descriptors described by `ranges`.
 
-        :param ranges: A sequence of `FileDescriptorRange` instances,
-            each describing a range of file descriptors to close.
+        :param ranges: A sequence of tuples `(low, high)`, each
+            describing a range of file descriptors to close.
         :return: ``None``.
 
         Attempt to close each open file descriptor – starting from
         `low` and ending before `high` – from each range in `ranges`.
         """
     for range in ranges:
-        os.closerange(range.low, range.high)
+        os.closerange(range[0], range[1])
 
 
 def close_all_open_files(exclude=None):
